@@ -1,4 +1,10 @@
-""" A simple and expressive Craigslist API wrapper. """
+"""
+pycraigslist API library
+~~~~~~~~~~~~~~~~~~~~~~~~
+
+pycraigslist is a fast and expressive Craigslist API wrapper,
+written in Python, for human beings.
+"""
 
 # fmt: off
 from .api import (community, events, forsale, gigs,
@@ -8,4 +14,4 @@ __all__ = ["community", "events", "forsale", "gigs",
            "housing", "jobs", "services", "resumes"]
 # fmt: on
 
-__version__ = "0.3.6"
+__version__ = "0.4.0"
