@@ -1,11 +1,17 @@
+"""
+pycraigslist.models.filters
+~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+This module parses and gets additional Craigslist query filters.
+"""
+
 from . import sessions
 
 
 def get_addl_readable(url):
     """Gets additional Craigslist query filters in readable format."""
     filters = get_addl(url)
-    filters_iter = filters.copy()
-    for key, value in filters_iter.items():
+    for key, value in filters.copy().items():
         if isinstance(value, dict):
             # get only filter names
             # e.g. ['apartment', 'condo'] from {'apartment': '1', 'condo': '2'}
@@ -31,31 +37,29 @@ def get_addl(url):
     return filters
 
 
-def parse(url, filters, search_filters):
+def parse(filters, search_filters):
     """Parses and validates url and filters using categorical search filters as
-    template reference. Returns filters for requests.get(params=)."""
-    addl_filters = get_addl(url)
-
+    template reference. Returns filters for requests.get params."""
     # iterate over a copy of filters
     for key, value in filters.copy().items():
+        if key in ("searchNearby", "s"):
+            # skip default filters found in all queries
+            continue
         try:
-            if key in addl_filters:
-                # addl_filters allow multiple values - assign all specified by user
-                filters[key] = [addl_filters[key][parsed_val] for parsed_val in parse_value(value)]
-            else:
-                # working with standard filters
-                try:
-                    # substitute and remove key for url_key
-                    url_key = search_filters.get(key)["url_key"]
-                    del filters[key]
-                # thrown when attempting to subscript 'searchNearby' or 's'
-                except TypeError:
-                    url_key = key
-                filters[url_key] = parse_value(value)
-
-        # bad value
-        except (KeyError, ValueError) as bad_value:
-            raise ValueError("%s is not a valid value for filter '%s'" % (bad_value, key))
+            # substitute and remove key for url_key
+            url_key = search_filters[key]["url_key"]
+            filters[url_key] = parse_value(value)
+            if url_key != key:
+                # delete old key
+                del filters[key]
+        except KeyError:
+            # some filters allow multiple values - assign all specified by user
+            try:
+                filters[key] = [
+                    search_filters[key][parsed_val] for parsed_val in parse_value(value)
+                ]
+            except (KeyError, TypeError):
+                raise ValueError("filter '%s' is or has a bad value" % key)
 
     return filters
 
@@ -68,9 +72,5 @@ def parse_value(filter_value):
     # returns bool or int as int
     if isinstance(filter_value, (bool, int)):
         return [int(filter_value)]
-    try:
-        # recursively parses values if filter_value is an iterable
-        return iter(parse_value(value) for value in filter_value)
-    except TypeError:
-        # overall a bad object, e.g. a class without and iterable
-        raise ValueError(filter_value)
+    # recursively parses values if filter_value is an iterable
+    return iter(parse_value(value)[0] for value in filter_value)
